Constructor
===========

.. currentmodule:: chaospy

Variable
--------

.. autosummary::
   :toctree: ../../api

   variable
   polynomial
   aspolynomial
   symbols
   polynomial_from_attributes
   ndpoly.from_attributes
   polynomial_from_roots

Expansion
---------

.. autosummary::
   :toctree: ../../api

   monomial
   expansion.lagrange

Orthogonal
----------

.. autosummary::
   :toctree: ../../api

   expansion.stieltjes
   expansion.cholesky
   expansion.gram_schmidt

Pre-defined orthogonal
~~~~~~~~~~~~~~~~~~~~~~

.. autosummary::
   :toctree: ../../api

   expansion.chebyshev_1
   expansion.chebyshev_2
   expansion.gegenbauer
   expansion.hermite
   expansion.jacobi
   expansion.laguerre
   expansion.legendre
